@@ -3,8 +3,8 @@ library("SPUTNIK")
 
 ## Create the msi.dataset-class object
 sz <- c(5, 4)
-x <- matrix(rnorm(sz[1] * sz[2]), sz[1], sz[2])
-mz <- seq(100, 195, 5)
+x <- matrix(rnorm(sz[1] * sz[2] * 20), sz[1]*sz[2], 20)
+mz <- sort(sample(100, ncol(x)))
 msiX <- msiDataset(x, mz, sz[1], sz[2])
 
 ## Get m/z vector
